import chimera, numpy as np
from StructBio.Scenographics.lines import Lines
from StructBio.Scenographics.solids import Solids
from StructBio.Scenographics.parametricSurfaces import FrenetFrameSurface

chimera.runCommand("set bg_color white")

num = 8     # Use a simple ellipse with 8 points
solids = Solids()

# Generate base curve as a low resolution ellipse.
basePts_L = []
basePts3D_L = []
for i in range(num):
    basePts_L.append(np.array([np.cos(i*2.*np.pi/num), 1.5*np.sin(i*2.*np.pi/num)]))
    basePts3D_L.append(np.array([np.cos(i*2.*np.pi/num), 1.5*np.sin(i*2.*np.pi/num), 0.0]))
# Put a "dent" in he ellipse to aid the veiwer in seeing the effects of a rotation.
basePts3D_L[2] = np.array([0., 1., 0.])
basePts_L[2] = np.array([0., 1.])

# Spheres for the base curve:
for v in basePts3D_L:
    solids.addSphere(v, .04, (1., 0., 0.))

# Spine points:
spinePts_L = [np.array([5., 1., 1.]), np.array([4., 2., 2.]), np.array([4., 4., 3.]), np.array([3., 6., 4.])]

# Rotation matrices:
rotMats_L = []
for i in range(4):
    u = i*np.pi/12.
    rotMats_L.append(np.array([[np.cos(u), np.sin(u), 0.],
                               [0.0, 0.0, 1.0], 
                               [np.sin(u), -np.cos(u), 0.]]).transpose())
# y scale values.
yScale_L = [1., .8, .6, .4]

# Generate the Frenet frame surface:
frenetFrameSurf = FrenetFrameSurface(basePts_L, spinePts_L, rotMats_L, [1.], yScale_L)
frenetFrameSurf.displayMesh((0., 0., 0.), closedBase = True, closedSpine = False)
frenetFrameSurf.displaySurface((0.4, .4, 0.4), .5, closedBase = True, closedSpine = False)

# Arrows to show the x, y, and z axes:
solids.addArrow(np.array((-1.5, 0., 0.)), np.array((1.5, 0., 0.)), .02, (1., 0., 0.))
solids.addArrow(np.array((0., -2., 0.)),  np.array((0., 2.0, 0.)), .02, (0., 1., 0.))
solids.addArrow(np.array((0., 0., -0.5)), np.array((0., 0.0, 1.)), .02, (0., 0., 1.))

# Spheres to emphasize points on the spine:
for v in spinePts_L:
    solids.addSphere(v, .05, (1., 0., 0.))
solids.display()

# Show lines for points on the base curve and the spine.
lines = Lines()
basePts3D_L.append(basePts3D_L[0]) # Closing the base curve for line display....
lines.addLine(basePts3D_L, (0.0, 0.0, 0.0))
lines.addLine(spinePts_L, (0.0, 0.0, 1.0))                
lines.display()
