import chimera, numpy as np
from StructBio.Scenographics.solids import Solids
from StructBio.Scenographics.parametricSurfaces import FrenetFrameSurface

chimera.runCommand("set bg_color white")
numBasePts = 16

# Make unit square of primary points:
seq = np.arange(-1., 1., 8.0/numBasePts)
basePts_L = [np.array([1., i]) for i in seq]
basePts_L.extend([np.array([i, 1.]) for i in -seq])
basePts_L.extend([np.array([-1, i]) for i in -seq])
basePts_L.extend([np.array([i, -1]) for i in seq])

# Show a set of small spheres to represent points in primary cross section:
spheres = Solids()
for pt in basePts_L:
    temp = list(pt)
    temp.append(0.0)
    spheres.addSphere(np.array(temp), .04, (1.0, 0., 0,))
spheres.display()

spinePts_L = []
rotMats_L = []
for u in np.arange(0.0, 2.0*np.pi, 2.0*np.pi/256, dtype = float):
    pt = 10.0 * np.array([np.cos(u), np.sin(u), 0.0])
    spinePts_L.append(pt)
    rotMats_L.append(np.array([[np.cos(u), np.sin(u), 0.],
                               [0.0, 0.0, 1.0], 
                               [np.sin(u), -np.cos(u), 0.]]).transpose())

frenetFrameSurf = FrenetFrameSurface(basePts_L, spinePts_L, rotMats_L, [1.], [1.])

# Use the next statement to get a mesh (at the expense of longer execution time).
#frenetFrameSurf.displayMesh((0., 1., 0.), closedBase = True, closedSpine = True)
frenetFrameSurf.displaySurface((.1, .4, .8), transparency = 1.0, closedBase = True, closedSpine = True)

chimera.runCommand("focus")
 
