import chimera, numpy as np
from StructBio.Scenographics.solids import Solids
from StructBio.Scenographics.parametricSurfaces import RevolutionSurface

chimera.runCommand("set bg_color white") # More dramatic in black...

# Vase:
numBasePts = 128
numCrossSections = 128

# Vase profile used for base curve:
a = 3.
b = 2.
r = 1.
h = 5.
basePts_L = [np.array([0.0, -b]), np.array([r - 0.2, -b]),
             np.array([r - 0.2, -b - 0.1]), np.array([r, -b - 0.1])]
for i in range(numBasePts):
    u  = i * np.pi/(numBasePts - 1) - np.pi/2
    basePts_L.append(np.array([r + a * np.cos(u), b * np.sin(u)]))
basePts_L.extend([np.array([r, h]), np.array([r + 0.3, h + 1.]), np.array([r + 0.2, h + 1]),
                  np.array([r - 0.1, h]), np.array([r - 0.1, b])])
    
"""
# Show a set of small spheres to represent points in base cross section:
spheres = Solids()
for pt in basePts_L:
    temp = list(pt)
    temp.append(0.0)
    spheres.addSphere(np.array(temp), .04, (1.0, 0., 0,))
spheres.display()
"""

revolutionSurf = RevolutionSurface(basePts_L, 0.0, 2.0 * np.pi, numCrossSections, [1.], [1.])

#revolutionSurf.displayMesh((0., 1., 0.), startCap = False, endCap = False,
#                       closedBase = False, closedSpine = False)

revolutionSurf.displaySurface((.54, .21, .06), transparency = 1.0, startCap = False, endCap = False,
                           closedBase = False, closedSpine = False)

chimera.runCommand("focus")
 
