import chimera, numpy as np
from StructBio.Scenographics.parametricSurfaces import RuledSurface
from StructBio.Scenographics.solids import Solids

chimera.runCommand("set bg_color white")

numFirstPts = 512
numCrossSections = 2

# Make unit square of first points:
seq = np.arange(-1., 1., 8.0/numFirstPts)
firstPts_L = [np.array([1., i, 0.0]) for i in seq]
firstPts_L.extend([np.array([i, 1., 0.0]) for i in -seq])
firstPts_L.extend([np.array([-1, i, 0.0]) for i in -seq])
firstPts_L.extend([np.array([i, -1, 0.0]) for i in seq])

thetaIncr = 2.0*np.pi/numFirstPts
thetaVals_L = [i*thetaIncr - np.pi/4 for i in range(numFirstPts)]
finalPts_L = [np.array([np.cos(theta), np.sin(theta), 2.]) for theta in thetaVals_L]

"""
# Show a set of small spheres to represent points in first and final cross sections:
spheres = Solids()
for pt in firstPts_L: spheres.addSphere(pt, .04, (1.0, 0., 0,))
for pt in finalPts_L: spheres.addSphere(pt, .04, (1.0, 0., 0,))
spheres.display()
"""

ruledSurf = RuledSurface(firstPts_L, finalPts_L, numCrossSections)

#ruledSurf.displayMesh((0., 1., 0.), closed = True, startCap = True, endCap = True)

# Capped
#ruledSurf.displaySurface((.14, .21, .56), transparency = .4, closed = True, startCap = True, endCap = True)

# Not capped:
ruledSurf.displaySurface((.14, .21, .56), transparency = .4, closed = True, startCap = False, endCap = False)

chimera.runCommand("focus")
 
